@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-"""Copyright (C) 2009-2014 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+"""Copyright (C) 2009-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
 Kajongg is free software you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -24,11 +24,12 @@ Read the user manual for a description of the interface to this scoring engine
 
 from itertools import chain
 
-from log import m18nc
+from mi18n import i18nc
+from common import StrMixin
 from tile import Tile, TileList, elements
 
 
-class Meld(TileList):
+class Meld(TileList, StrMixin):
 
     """represents a meld. Can be empty. Many Meld methods will
     raise exceptions if the meld is empty. But we do not care,
@@ -323,42 +324,38 @@ class Meld(TileList):
             return len(self) > len(other)
         return self[0].key < other[0].key
 
-    def __repr__(self):
-        """the default representation"""
-        return 'Meld(%s)' % str(self)
-
     def typeName(self):
         """convert int to speaking name with shortcut. ATTENTION: UNTRANSLATED!"""
         # pylint: disable=too-many-return-statements
         if self.isBonus:
-            return m18nc('kajongg meld type', 'Bonus')
+            return i18nc('kajongg meld type', 'Bonus')
         elif self.isSingle:
-            return m18nc('kajongg meld type', '&single')
+            return i18nc('kajongg meld type', '&single')
         elif self.isPair:
-            return m18nc('kajongg meld type', '&pair')
+            return i18nc('kajongg meld type', '&pair')
         elif self.isChow:
-            return m18nc('kajongg meld type', '&chow')
+            return i18nc('kajongg meld type', '&chow')
         elif self.isPung:
-            return m18nc('kajongg meld type', 'p&ung')
+            return i18nc('kajongg meld type', 'p&ung')
         elif self.isClaimedKong:
-            return m18nc('kajongg meld type', 'c&laimed kong')
+            return i18nc('kajongg meld type', 'c&laimed kong')
         elif self.isKong:
-            return m18nc('kajongg meld type', 'k&ong')
+            return i18nc('kajongg meld type', 'k&ong')
         else:
-            return m18nc('kajongg meld type', 'rest of tiles')
+            return i18nc('kajongg meld type', 'rest of tiles')
 
     def __stateName(self):
         """the translated name of the state"""
         if self.isBonus or self.isClaimedKong:
             return ''
         elif self.isExposed:
-            return m18nc('kajongg meld state', 'Exposed')
+            return i18nc('kajongg meld state', 'Exposed')
         else:
-            return m18nc('kajongg meld state', 'Concealed')
+            return i18nc('kajongg meld state', 'Concealed')
 
     def name(self):
         """the long name"""
-        result = m18nc(
+        result = i18nc(
             'kajongg meld name, do not translate parameter names',
             '{state} {meldType} {name}')
         return result.format(
